# Introduction

Notion Connect is a Python extension that helps make Notion more useful for LLM applications.

It aims to help simplify the process of extracting information from Notion and integrating it with other systems.

# Installation

```bash
pip install notion-connect
```

This is a new project, there's a lot of work to be done so do temper your expectations.

[ ] Add support for downloading notion pages
[ ] Add support for converting raw JSON blocks to markdown
[ ] Add support for creating comments and new notion pages
[ ] Add chunking support for pages that links back to the parent chunk.

Note that we're supporting a subset of features for now, if things break feel free to open an issue.
